@@ -24,7 +24,7 @@ use warnings;
 no warnings;
 use vars qw($VERSION);
 
-$VERSION = '2.07_01';
+$VERSION = '2.121_02';
 
 use Carp qw(carp croak);
 use File::Basename qw(dirname);
@@ -467,7 +467,25 @@ Added in 1.21.
 
 =cut
 
-sub perls { keys %{ $_[0]->{perls} } }
+sub perls {
+    my $self = shift;
+
+    my @perls = keys %{$self->{perls}};
+	warn "perls are [@perls]\n";
+
+    # Sort them
+    @perls =
+	map  { $_->[0] }
+	sort { $a->[2] <=> $b->[2] || $a->[3] <=> $b->[3] || $a->[0] cmp $b->[0] }
+	map  { [ $_->[0], ( $_->[1] =~ m/(perl5\.(?|([0-9]{3})_?([0-9]{2})|([0-9]{1,2})\.([0-9]+)))/) ] }
+	map  { [ $_, (m{.*/(.*)}) ] }
+	grep { -x $_ }
+	@perls;
+	warn "perls are [@perls]\n";
+
+    warn "Testing with ", scalar @perls, " versions of perl\n";
+    return @perls;
+    }
 
 =item add_a_perl( PATH )
 
@@ -560,7 +578,10 @@ return whatever they like.
 
 =cut
 
-sub null_fh  { $_[0]->{null_fh} }
+sub null_fh  {
+	require IO::Null;
+	$_[0]->{null_fh} //= IO::Null->new;
+	}
 
 =item quiet
 
@@ -606,11 +627,12 @@ sub turn_debug_off { $_[0]->{debug} = 0 }
 sub debug          { $_[0]->{debug} }
 
 sub debug_fh  {
-	$_[0]->debug
-		?
-	( $_[0]->{debug_fh} || *STDERR{IO} )
-		:
-	$_[0]->null_fh
+		if( $_[0]->debug ) {
+			$_[0]->{debug_fh} || *STDERR{IO}
+			}
+		else {
+			$_[0]->null_fh
+			}
 	}
 
 =back
@@ -828,19 +850,46 @@ Return the distribution version ( set in dist() )
 
 =cut
 
-sub dist_version {
-	my $self = shift;
+sub _parse_version {
+	my( $self ) = @_;
+	no warnings 'uninitialized';
 
 	$self->_die( "Can't get dist_version! It's not set (did you run dist first?)" )
 		unless defined $self->remote_file;
 
-	no warnings 'uninitialized';
-	my ($version_str, $vee, $version) = $self->remote_file
-		=~ / ( (v?) ([\d_.]+) ) (?:\. tar \. gz)? $/xi
-			or return '';
+	my( $version_str, $vee, $version, $dev ) = $self->remote_file
+		=~ / ( (v?) ([\d.]+) (?: _ (\d+) )? ) (?:\. (?: tar \. gz | zip ) )? $/xi
+			or return { components => [], string => '', multipart => 0 };
 
 	my @components = split /[.]/, $version;
-	if ($vee || @components > 2) { # This is a multi-part version
+	my $count      = @components;
+
+	my $multipart  = length($vee) || ($count > 2);
+
+	my $hash = {
+		components => \@components,
+		count      => $count,
+		string     => $version_str,
+		vee        => lc $vee,
+		version    => $version,
+		v_version  => lc($vee) . $version,
+		dev        => $dev,
+		multipart  => $multipart,
+		};
+
+	$self->_debug( Dumper( $self->remote_file, $hash ) ); use Data::Dumper;
+
+	return $hash;
+	}
+
+sub dist_version {
+	my( $self ) = @_;
+
+	my $v = $self->_parse_version;
+
+	if( $v->{multipart} ) {
+		$self->_debug( "Choosing multipart version" );
+		# This is a multi-part version
 		# We assume that version.pm is available if multi-part
 		# versions are in use.
 		eval {
@@ -848,33 +897,44 @@ sub dist_version {
 			}
 		or do { # Fall back to using $version_str verbatim
 			warn $@;
-			return $version_str;
+			return $v->{version_str};
 			};
 
 		# There are pre- and post-0.77 versions of version.pm.
 		# The former are deprecated, but I assume we must
 		# gracefully use what we have available.
 		eval {
-			$version = version->VERSION >= 0.77?
-				version->parse (lc($vee) . $version)->normal : # latest and best
-				''.version->new(lc($vee) . $version)         ; # legacy
+			my $string = $v->{v_version};
+			$v->{version} = version->VERSION >= 0.77 ?
+				version->parse ($string)->normal : # latest and best
+				''.version->new($string)         ; # legacy
 			1;
 			}
 		or
-			$self->_die( "Couldn't parse version '$version_str' from '".
+			$self->_die( "Couldn't parse version '$v->{string}' from '".
 				$self->remote_file. "': $@");
 
-		return $version;
+		return $v->{version};
+		}
+	elsif( $v->{count} == 1 ) {
+		$self->_debug( "Choosing single component version" );
+		# some versions might be a single number, such as those
+		# that use dates as integers with no dot.
+		return $v->{components}[0];
+		}
+	elsif( $v->{string} =~ /(\d+) \. (\d+)(_\d+)? $/x ) {
+		$self->_debug( "Choosing major.minor_dev? version" );
+		# Else, use the older implementation for backward-compatibility
+		# Note the lack of an initial ^ matcher is deliberate.
+		my( $major, $minor, $dev ) = ( $1, $2, $3 );
+		return $self->dist_version_format( $major, $minor, $dev );
+		}
+	else {
+		$self->_debug( "Unhandled version" );
+		return '';
 		}
 
 
-	# Else, use the older implementation for backward-compatibility
-	# Note the lack of an initial ^ matcher is deliberate.
-
-	my( $major, $minor, $dev ) =
-		$version_str =~ /(\d+) \. (\d+)(_\d+)? $/xg;
-
-	return $self->dist_version_format( $major, $minor, $dev );
 	}
 
 =item dist_version_format
@@ -890,7 +950,7 @@ sub dist_version_format {
 	my $self = shift;
 	my( $major, $minor, $dev ) = @_;
 
-	sprintf "%d.%02d%s", $major, $minor, $dev;
+	sprintf "%s.%s%s", $major, $minor, $dev;
 	}
 
 =item check_manifest
@@ -935,7 +995,6 @@ sub _check_output_lines {
 		$self->_print( "\n\t$message_hash->{$key}\n\t$rule\n\t@$list\n" );
 		}
 
-
 	return $count;
 	}
 
@@ -1150,7 +1209,7 @@ you may well want to overload it.
 =cut
 
 sub get_changes {
-	open my $fh, '<', 'Changes' or return '';
+	open my $fh, '<:utf8', 'Changes' or return '';
 
 	my $data = <$fh>;  # get first line
 
@@ -1266,8 +1325,17 @@ Send the LIST to whatever is in debug_fh, or to STDERR. If you aren't
 debugging, debug_fh should return a null filehandle.
 
 =cut
+use Carp qw(carp);
+sub _debug {
+	my $self = shift;
 
-sub _debug { print { $_[0]->debug_fh } @_[1..$#_] }
+	my $debug_fh = $self->debug_fh;
+
+	print { $debug_fh } @_;
+	}
+
+
+#eval { print { shift->debug_fh } @_; 1 } or carp "Failure in _debug: [@_] [$@]" }
 
 =item _die( LIST )
 
@@ -1313,7 +1381,7 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2002-2013 brian d foy.  All rights reserved.
+Copyright © 2002-2016, brian d foy <bdfoy@cpan.org>. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
