@@ -2,7 +2,7 @@ package Module::Release::FTP;
 
 use strict;
 use warnings;
-use base qw(Exporter);
+use Exporter qw(import);
 use vars qw($VERSION);
 
 use Carp qw(croak);
@@ -14,7 +14,7 @@ our @EXPORT = qw(
 	default_ftp_password default_ftp_upload_dir
 	);
 
-$VERSION = '2.07_01';
+$VERSION = '2.121_02';
 
 =encoding utf8
 
@@ -25,10 +25,8 @@ Module::Release::FTP - Interact with an FTP server
 =head1 SYNOPSIS
 
 NOTE: PAUSE has turned off FTP uploads. Methods in this class
-will croak.
-
-The release script automatically loads this module when it's time
-to upload a file
+will croak. If you want to make a private PAUSE with FTP, you
+can adapt this manual.
 
 =head1 DESCRIPTION
 
@@ -206,7 +204,7 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2007-2013, brian d foy, All Rights Reserved.
+Copyright © 2007-2016, brian d foy <bdfoy@cpan.org>. All rights reserved.
 
 You may redistribute this under the same terms as Perl itself.
 
