@@ -2,7 +2,7 @@ package Module::Release::PAUSE;
 
 use strict;
 use warnings;
-use base qw(Exporter);
+use Exporter qw(import);
 use vars qw($VERSION);
 
 use Carp qw(croak);
@@ -10,7 +10,7 @@ use Carp qw(croak);
 our @EXPORT = qw(
 	);
 
-$VERSION = '2.07_01';
+$VERSION = '2.121_02';
 
 =encoding utf8
 
@@ -47,7 +47,7 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2007-2013, brian d foy, All Rights Reserved.
+Copyright © 2007-2016, brian d foy <bdfoy@cpan.org>. All rights reserved.
 
 You may redistribute this under the same terms as Perl itself.
 
