@@ -2,18 +2,18 @@ package Module::Release::Prereq;
 
 use strict;
 use warnings;
-use base qw(Exporter);
+use Exporter qw(import);
 use vars qw($VERSION);
 
 our @EXPORT = qw( check_prereqs _get_prereq_ignore_list );
 
-$VERSION = '2.07_01';
+$VERSION = '2.121_02';
 
 =encoding utf8
 
 =head1 NAME
 
-Module::Release::Prereq - Check  pre-requisites list in build file
+Module::Release::Prereq - Check pre-requisites list in build file
 
 =head1 SYNOPSIS
 
@@ -78,7 +78,7 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2007-2013, brian d foy, All Rights Reserved.
+Copyright © 2007-2016, brian d foy <bdfoy@cpan.org>. All rights reserved.
 
 You may redistribute this under the same terms as Perl itself.
 
