@@ -2,7 +2,7 @@ package Module::Release::WebUpload::Mojo;
 
 use strict;
 use warnings;
-use base qw(Exporter);
+use Exporter qw(import);
 use vars qw($VERSION);
 
 use Carp qw(croak);
@@ -16,7 +16,7 @@ our @EXPORT = qw(
 	pause_add_uri
 	);
 
-$VERSION = '2.07_01';
+$VERSION = '2.121_02';
 
 =encoding utf8
 
@@ -56,14 +56,23 @@ sub web_upload {
 
 	$self->_print( "File uploading\n" );
 	my $tx = $ua->post(
-		$self->pause_add_uri( 
-		 	$self->config->cpan_user, 
+		$self->pause_add_uri(
+		 	$self->config->cpan_user,
 		 	$self->config->cpan_pass,
 		 	),
 		 form => $params,
 		 );
-	my $code = $tx->res->code;
-	$self->_print( "File uploaded [$code]\n" );
+
+	if( my $res = $tx->success ) {
+		$self->_print( "File uploaded\n" );
+		return 1;
+		}
+	else {
+		my $err = $tx->error;
+		$self->_print( "$err->{code} response: $err->{message}" ) if $err->{code};
+		$self->_print( "Connection error: $err->{message}" );
+		return 0;
+		}
 	}
 
 sub make_agent {
@@ -72,12 +81,50 @@ sub make_agent {
 	$agent->transactor->name( 'release' );
 	$agent->http_proxy( $self->config->http_proxy ) if $self->config->http_proxy;
 	$agent->https_proxy( $self->config->https_proxy ) if $self->config->https_proxy;
-	require CACertOrg::CA;
-	$agent->cert( CACertOrg::CA::SSL_ca_file() );
 
 	return $agent;
 	}
 
+# XXX: Until I can upgrade OpenSSL
+BEGIN {
+use Mojo::IOLoop::Client;
+
+use constant TLS => $ENV{MOJO_NO_TLS}
+  ? 0
+  : eval 'use IO::Socket::SSL 1.94 (); 1';
+
+no warnings 'redefine';
+sub Mojo::IOLoop::Client::_try_tls {
+  my ($self, $args) = @_;
+
+  my $handle = $self->{handle};
+  return $self->_cleanup->emit(connect => $handle) unless $args->{tls};
+  return $self->emit(error => 'IO::Socket::SSL 1.94+ required for TLS support')
+    unless TLS;
+
+  # Upgrade
+  weaken $self;
+  my %options = (
+    SSL_ca_file => $args->{tls_ca}
+      && -T $args->{tls_ca} ? $args->{tls_ca} : undef,
+    SSL_cert_file  => $args->{tls_cert},
+    SSL_error_trap => sub { $self->emit(error => $_[1]) },
+    SSL_hostname   => IO::Socket::SSL->can_client_sni ? $args->{address} : '',
+    SSL_key_file   => $args->{tls_key},
+    SSL_startHandshake  => 0,
+    SSL_verify_mode     => 0x00,  # XXX turn off hostname verification
+    SSL_verifycn_name   => $args->{address},
+    SSL_verifycn_scheme => $args->{tls_ca} ? 'http' : undef
+  );
+
+  my $reactor = $self->reactor;
+  $reactor->remove($handle);
+  return $self->emit(error => 'TLS upgrade failed')
+    unless IO::Socket::SSL->start_SSL($handle, %options);
+  $reactor->io($handle => sub { $self->_tls })->watch($handle, 0, 1);
+}
+}
+
 =back
 
 =head2 Default values
@@ -122,7 +169,7 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2007-2013, brian d foy, All Rights Reserved.
+Copyright © 2007-2016, brian d foy <bdfoy@cpan.org>. All rights reserved.
 
 You may redistribute this under the same terms as Perl itself.
 
